==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-finnish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Kaikki kanavat");
define("_NOCOMMENTS","Ei kommentteja");
define("_UCOMMENT","Kommenttia");
define("_REVIEWS","Arvostelut");
define("_SEARCHUSERS","Etsi kyttjist:");
define("_SEARCHSECTIONS","Etsi erikoisaihealueista:");
define("_SEARCHREVIEWS","Etsi arvosteluista:");
define("_SEARCHIN","Etsint:");
define("_ARTICLES","Artikkelit");
define("_ALLAUTHORS","Kaikki kirjoittajat");
define("_ALL","Kaikki");
define("_WEEK","viikko");
define("_WEEKS","viikot");
define("_MONTH","kuukausi");
define("_MONTHS","kuukaudet");
define("_SEARCHON","Etsi:");
define("_SSTORIES","Artikkelit");
define("_SSECTIONS","Aihepiirit");
define("_SUSERS","Kyttjt");
define("_NOMATCHES","Tietoja antamillasi hakuehdoilla ei lytynyt");
define("_PREVMATCHES","edellinen sivu hakutuloksissa");
define("_NEXTMATCHES","seuraava sivu hakutuloksissa");
define("_INSECTION","Artikkeli aihepiiriss");
define("_NONAME","Nime ei ole sytetty");
define("_SCOMMENTS","Kommentit");
define("_SEARCHRESULTS","Hakutulokset");
define("_CONTRIBUTEDBY","Kirjoittanut:");
define("_UCOMMENTS","Kommentia");
define("_MATCHTITLE","Hakusana lytyi otsikosta");
define("_MATCHTEXT","Hakusana lytyi artikkelin tekstist");
define("_MATCHBOTH","Hakusana lytyi otsikosta ja artikkelin tekstist");
define("_SREPLY","Vastaa");
define("_SREPLIES","Vastaukset");
define("_ATTACHART","Liitetty artikkeliin");
define("_PAGES","Sivut");
define("_REVIEWSCORE","Arvostelun pisteet");
define("_PAGE","sivu");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-finnish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Kaikki kanavat");
define("_NOCOMMENTS","Ei kommentteja");
define("_UCOMMENT","Kommenttia");
define("_REVIEWS","Arvostelut");
define("_SEARCHUSERS","Etsi kyttjist:");
define("_SEARCHSECTIONS","Etsi erikoisaihealueista:");
define("_SEARCHREVIEWS","Etsi arvosteluista:");
define("_SEARCHIN","Etsint:");
define("_ARTICLES","Artikkelit");
define("_ALLAUTHORS","Kaikki kirjoittajat");
define("_ALL","Kaikki");
define("_WEEK","viikko");
define("_WEEKS","viikot");
define("_MONTH","kuukausi");
define("_MONTHS","kuukaudet");
define("_SEARCHON","Etsi:");
define("_SSTORIES","Artikkelit");
define("_SSECTIONS","Aihepiirit");
define("_SUSERS","Kyttjt");
define("_NOMATCHES","Tietoja antamillasi hakuehdoilla ei lytynyt");
define("_PREVMATCHES","edellinen sivu hakutuloksissa");
define("_NEXTMATCHES","seuraava sivu hakutuloksissa");
define("_INSECTION","Artikkeli aihepiiriss");
define("_NONAME","Nime ei ole sytetty");
define("_SCOMMENTS","Kommentit");
define("_SEARCHRESULTS","Hakutulokset");
define("_CONTRIBUTEDBY","Kirjoittanut:");
define("_UCOMMENTS","Kommentia");
define("_MATCHTITLE","Hakusana lytyi otsikosta");
define("_MATCHTEXT","Hakusana lytyi artikkelin tekstist");
define("_MATCHBOTH","Hakusana lytyi otsikosta ja artikkelin tekstist");
define("_SREPLY","Vastaa");
define("_SREPLIES","Vastaukset");
define("_ATTACHART","Liitetty artikkeliin");
define("_PAGES","Sivut");
define("_REVIEWSCORE","Arvostelun pisteet");
define("_PAGE","sivu");

?>
